!Splitbar Resizing Methods
! Copyright 1999-2001 JNData, LLC
! 2-13-1999  - Added bug fix to account for a bar that cannot move
!              and for bars that are very wide/high.
! 2-15-199   - Added bug fix for C4 - Events (Drag, Dragging, and mousemove) were not getting
!              trapped by the REGISTEREVENT handler. So, now have a C4 and a C5 Template.
!              The Object Defs are different. We will not trap events via Register Event.
! 2-15-1999  - We will be using RegisterEvent of C5.
! 4-6-1999   - Added the ability to redraw the fields as the bar is being moved.
! 5-30-2000  - Removed the ABC Linking and DLL Mode Equates for C5.5 compatibility
!              Current Template Version is 1.20
! 11-11-2000 - Discovered bug with C5.5 gold. Added "UnregisterEvents" to kill method (previously unnecessary).
! 02-26-2001 - Added a small bug fix in redraw methods to fix a tiny display problem when bar had reached a right or bottom edge.
! 02-27-2001 - Remove use of "SYSTEM{PROP:DeferMove}" in RedrawFields method due to bug when deferring moves of REGIONS in C5.5 gold.
! 02-28-2001 - Added Pointer Bar Offset to keep wide/fat bars from "jumping" when first touched.
!            - Added use of SaveBarLook and ReSetBarLook to save and restore bar appearance.
! 02-28-2001 - Issued new template version "1.25" for C4-C5.5
! 08-09-2001 - Testing with C5.5 Patch 5
!            - Revised Init and Add method to use bar's Control Number
!            - When registering the Event Handlers.
!            - Changed Drag Event handler to be MouseUp Event Handler. It does the same job.
!            - Added the use of a shadowing panel control to reduce flicker of the bar when being moved.
! 08-10-2001 -  New Version of Template (1.26) to handle new Event (MouseUp).
! 08-13-2001 - Finally resolved use of "shadowing" panel. Using the panel only when "redrawing" fields during bar move.
!            - Otherwise, just the regular region is being displayed.
! 08-15-2001 - Small adjustment to the bevels of the panel. Panels look just like regions
!            - unless the Inner and outer bevels of the region are both zero. Then, to make
!            - the panel look lust like the region the inner bevel must be -1 instead of 0.

  MEMBER()

   OMIT('LinkEquates',_VER_C55)
_ABCDllMode_  EQUATE(0)
_ABCLinkMode_ EQUATE(1)
   ! LinkEquates

    MAP
    END !LOCAL MAP

  INCLUDE('JNDSPLIT.INC')
  INCLUDE('EQUATES.CLW')
  INCLUDE('ABERROR.INC')


JNDSplitManagerClass.Init PROCEDURE(BYTE DontUseEventTrap=0)
                            CODE

                            SELF.SQ &= NEW(JNDSplitQueue)
                            ASSERT(NOT(SELF.SQ &= NULL))
                            SELF.SFQ &= NEW(JNDSplitFieldQueue)
                            ASSERT(NOT(SELF.SFQ &= NULL))
                            SELF.MovingSplit = FALSE
                            SELF.EdgeBuffer = 5   ! DL's by default. Do something different if needed.

                            IF NOT DontUseEventTrap
                              SELF.RegisterEvents = TRUE
                            ELSE
                              SELF.RegisterEvents = FALSE
                            END !IF

                            SELF.OverlayBoxFEQ = LASTFIELD() + 1
                            CREATE(SELF.OverlayBoxFEQ,CREATE:Panel) ! Create a Panel Box to overlay
                            SELF.OverLayBoxFEQ{PROP:Hide} = 1   ! the Bar Region to reduce Flicker.
                                             ! If the fileds are to be redrawn while moving,
                                             ! then this panel control will be displayed to
                                             ! eliminate the flicker seen when using only regions.
                          RETURN

JNDSplitManagerClass.Kill PROCEDURE()
QSize       LONG
Counter     LONG
                            CODE
                            IF SELF.RegisterEvents
                              QSize = RECORDS(SELF.SQ)
                              LOOP Counter = QSize TO 1 BY -1
                                GET(SELF.SQ,Counter)
                                IF SELF.SQ.EventsRegistered
                                  UNREGISTEREVENT(EVENT:MouseMove,ADDRESS(SELF.TakeMouseMoveEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                  UNREGISTEREVENT(EVENT:MouseUp,ADDRESS(SELF.TakeMouseUpEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                  UNREGISTEREVENT(EVENT:Dragging,ADDRESS(SELF.TakeDraggingEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                  SELF.SQ.EventsRegistered = FALSE
                                  PUT(SELF.SQ)
                                END !IF
                              END !LOOP
                            END !IF
        
                            IF NOT (SELF.SQ &= NULL)
                              FREE(SELF.SQ)
                              DISPOSE(SELF.SQ)
                            END !IF

                            IF NOT (SELF.SFQ &= NULL)
                              FREE(SELF.SFQ)
                              DISPOSE(SELF.SFQ)
                            END !IF
                          RETURN

JNDSplitManagerClass.AddVertSplit   PROCEDURE(LONG PassedFEQ)     !  ,LONG  ! Returns Handle of the bar
ReturnHandle                            LONG

                                        CODE
                                        ReturnHandle = RECORDS(SELF.SQ) + 1
                                        SELF.SQ.BarHandle = ReturnHandle
                                        SELF.SQ.FEQ = PassedFEQ
                                        SELF.SQ.SplitType = JNDSplitType:Vertical
                                        SELF.SQ.RedrawWhileMoving = FALSE
                                        IF SELF.RegisterEvents
                                          REGISTEREVENT(EVENT:MouseMove,ADDRESS(SELF.TakeMouseMoveEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                          REGISTEREVENT(EVENT:MouseUp,ADDRESS(SELF.TakeMouseUpEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                          REGISTEREVENT(EVENT:Dragging,ADDRESS(SELF.TakeDraggingEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                          SELF.SQ.EventsRegistered = TRUE
                                        ELSE
                                          SELF.SQ.EventsRegistered = FALSE
                                        END !IF
                                        ADD(SELF.SQ,SELF.SQ.FEQ)  ! Sorted by FEQ for fast lookup
                                        ASSERT(NOT ERRORCODE())
                                        PassedFEQ{PROP:IMM} = '1'
                                        RETURN(ReturnHandle)


JNDSplitManagerClass.AddHorzSplit   PROCEDURE(LONG PassedFEQ)      !  ,LONG  ! Returns Handle of the bar
ReturnHandle                            LONG

                                        CODE
                                        ReturnHandle = RECORDS(SELF.SQ) + 1
                                        SELF.SQ.BarHandle = ReturnHandle
                                        SELF.SQ.FEQ = PassedFEQ
                                        SELF.SQ.SplitType = JNDSplitType:Horizontal
                                        SELF.SQ.RedrawWhileMoving = FALSE
                                        IF SELF.RegisterEvents
                                          REGISTEREVENT(EVENT:MouseMove,ADDRESS(SELF.TakeMouseMoveEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                          REGISTEREVENT(EVENT:MouseUp,ADDRESS(SELF.TakeMouseUpEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                          REGISTEREVENT(EVENT:Dragging,ADDRESS(SELF.TakeDraggingEvent),ADDRESS(SELF),,SELF.SQ.FEQ)
                                          SELF.SQ.EventsRegistered = TRUE
                                        ELSE
                                          SELF.SQ.EventsRegistered = FALSE
                                        END !IF
                                        ADD(SELF.SQ,SELF.SQ.FEQ)  ! Sorted by FEQ for fast lookup
                                        ASSERT(NOT ERRORCODE())
                                        PassedFEQ{PROP:IMM} = '1'
                                        RETURN(ReturnHandle)

JNDSplitManagerClass.AddFieldServer PROCEDURE(LONG BarHandle,LONG PassedFEQ,BYTE MoveFlag,BYTE Placement)    ! ,BYTE
ReturnValue             BYTE
                        CODE

                          SELF.SFQ.BarHandle = BarHandle
                          SELF.SFQ.FEQ = PassedFEQ
                          SELF.SFQ.Placement = Placement
                          SELF.SFQ.MoveFlag = MoveFlag
                          ADD(SELF.SFQ,SELF.SFQ.BarHandle)
                          IF ERRORCODE()
                            ReturnValue = LEvel:Notify
                          END !IF
                          RETURN(ReturnValue)


JNDSplitManagerClass.AddFieldAbove  PROCEDURE(LONG BarHandle,LONG PassedFEQ,<BYTE MoveFlag>)    ! ,BYTE,PROC
ReturnValue             BYTE

                          CODE
                          SELF.SQ.BarHandle = BarHandle
                          GET(SELF.SQ,SELF.SQ.BarHandle)
                          ASSERT(NOT ERRORCODE())

                          IF OMITTED(4)   !  MoveFlag
                            MoveFlag = FALSE
                          END !IF
                          ReturnValue = SELF.AddFieldServer(BarHandle,PassedFEQ,MoveFlag,JNDSplitPlacement:Above)
                          RETURN(ReturnValue)

JNDSplitManagerClass.AddFieldBelow  PROCEDURE(LONG BarHandle,LONG PassedFEQ,<BYTE MoveFlag>)    ! ,BYTE,PROC
ReturnValue             BYTE
                          CODE
                          SELF.SQ.BarHandle = BarHandle
                          GET(SELF.SQ,SELF.SQ.BarHandle)
                          ASSERT(NOT ERRORCODE())

                          IF OMITTED(4)   !  MoveFlag
                            MoveFlag = FALSE
                          END !IF
                          ReturnValue = SELF.AddFieldServer(BarHandle,PassedFEQ,MoveFlag,JNDSplitPlacement:Below)
                          RETURN(ReturnValue)

JNDSplitManagerClass.AddFieldLeft   PROCEDURE(LONG BarHandle,LONG PassedFEQ,<BYTE MoveFlag>)    ! ,BYTE,PROC
ReturnValue             BYTE
                          CODE
                          SELF.SQ.BarHandle = BarHandle
                          GET(SELF.SQ,SELF.SQ.BarHandle)
                          ASSERT(NOT ERRORCODE())

                          IF OMITTED(4)   !  MoveFlag
                            MoveFlag = FALSE
                          END !IF
                          ReturnValue = SELF.AddFieldServer(BarHandle,PassedFEQ,MoveFlag,JNDSplitPlacement:Left)
                          RETURN(ReturnValue)

JNDSplitManagerClass.AddFieldRight  PROCEDURE(LONG BarHandle,LONG PassedFEQ,<BYTE MoveFlag>)    ! ,BYTE,PROC
ReturnValue             BYTE
                          CODE
                          SELF.SQ.BarHandle = BarHandle
                          GET(SELF.SQ,SELF.SQ.BarHandle)
                          ASSERT(NOT ERRORCODE())

                          IF OMITTED(4)   !  MoveFlag
                            MoveFlag = FALSE
                          END !IF
                          ReturnValue = SELF.AddFieldServer(BarHandle,PassedFEQ,MoveFlag,JNDSplitPlacement:Right)
                          RETURN(ReturnValue)

JNDSplitManagerClass.SetBarRedrawFlag   PROCEDURE(LONG BarHandle,BYTE RedrawFlag)
                          CODE
                          SELF.SQ.BarHandle = BarHandle
                          GET(SELF.SQ,SELF.SQ.BarHandle)
                          ASSERT(NOT ERRORCODE())
                          SELF.SQ.RedrawWhileMoving = RedrawFlag
                          PUT(SELF.SQ)
                          RETURN

JNDSplitManagerClass.SetMovingLimits  PROCEDURE(LONG BarHandle,BYTE Direction)
LowerLimit                 LONG
LowerOffset                LONG
UpperLimit                 LONG
UpperOffset                LONG
TempOffset                 LONG
Count                      LONG
BarPos                     LONG
BarSize                    LONG
FieldPos                   LONG
FieldSize                  LONG

            CODE

            LowerLimit = SELF.EdgeBuffer
            LowerOffset = 0

            IF Direction = JNDSplitMove:EastWest  ! Vertical Bar
              UpperLimit = (0{PROP:Width} - SELF.EdgeBuffer) - SELF.FEQBeingMoved{PROP:Width}
            ELSE
              UpperLimit = (0{PROP:Height} - SELF.EdgeBuffer) - SELF.FEQBeingMoved{PROP:Height}
            END !IF
            UpperOffset = 0

            LOOP Count = 1 TO RECORDS(SELF.SFQ)   ! Loop through all fields
               GET(SELF.SFQ,Count)

               IF SELF.SFQ.BarHandle = BarHandle
                 CASE SELF.SFQ.Placement
                   OF JNDSplitPlacement:Above
                   OROF JNDSplitPlacement:Below
                     BarPos = SELF.FEQBeingMoved{PROP:YPos}
                     BarSize = SELF.FEQBeingMoved{PROP:Height}
                     FieldPos = SELF.SFQ.FEQ{PROP:YPos}
                     FieldSize = SELF.SFQ.FEQ{PROP:Height}

                   OF JNDSplitPlacement:Left
                   OROF JNDSplitPlacement:Right
                     BarPos = SELF.FEQBeingMoved{PROP:XPos}
                     BarSize = SELF.FEQBeingMoved{PROP:Width}
                     FieldPos = SELF.SFQ.FEQ{PROP:XPos}
                     FieldSize = SELF.SFQ.FEQ{PROP:Width}

                   ELSE
                     ASSERT(FALSE)
                 END !CASE

                 CASE SELF.SFQ.Placement
                   OF JNDSplitPlacement:Above
                   OROF JNDSplitPlacement:Left
                     
                     IF SELF.SFQ.MoveFlag = FALSE   ! Not Moving
                       IF (FieldPos + SELF.EdgeBuffer) > LowerLimit
                         LowerLimit = FieldPos + SELF.EdgeBuffer
                       END !IF

                       TempOffset = (BarPos - (FieldPos + FieldSize))
                       SELF.SFQ.Offset = TempOffset
                       PUT(SELF.SFQ)
                       IF TempOffset > LowerOffset
                         LowerOffset = TempOffset
                       END !IF

                     ELSE      ! We are to Move this control - So Ignore its resizing
                       TempOffset = (BarPos - (FieldPos + FieldSize))   ! but record its real
                       SELF.SFQ.Offset = TempOffset                     ! offset. Then set
                       PUT(SELF.SFQ)                                    ! lower offset to its
                       TempOffset = BarPos - FieldPos                   ! farthest edge.
                       IF TempOffset > LowerOffset
                         LowerOffset = TempOffset
                       END !IF
                     END !IF

                   OF JNDSplitPlacement:Below
                   OROF JNDSplitPlacement:Right
                     IF SELF.SFQ.MoveFlag = FALSE
                       IF ((FieldPos + FieldSize) - SELF.EdgeBuffer) < UpperLimit
                         UpperLimit = (FieldPos + FieldSize) - SELF.EdgeBuffer
                       END !IF

                       TempOffset = FieldPos - (BarPos + BarSize)
                       SELF.SFQ.Offset = TempOffset
                       PUT(SELF.SFQ)
                       IF TempOffset > UpperOffset
                         UpperOffset = TempOffset
                       END !IF
                     ELSE      ! We are to move this control - So ignore its resizing but
                       TempOffset = FieldPos - (BarPos + BarSize)   ! its real offset. Then calc
                       SELF.SFQ.Offset = TempOffset                 ! upper offset from the
                       PUT(SELF.SFQ)                                ! farthest edge of the control
                       Tempoffset = (FieldPos + FieldSize) - (BarPos + BarSize)
                       IF TempOffset > UpperOffset
                         UpperOffset = TempOffset
                       END !IF
                     END !IF

                 END !CASE

               END !IF
            END !LOOP
            SELF.MinimumPos = (LowerLimit + LowerOffset)    
            SELF.MaximumPos = ((UpperLimit - UpperOffset) - (BarSize))
                                                                       ! 2-13-1999 bug fix noticed
                                                                       ! when placing wide/high
            RETURN



JNDSplitManagerClass.TakeMouseMoveEvent PROCEDURE()
ReturnValue                 BYTE
CurrentPos                  LONG
CurrentSize                 LONG
PointerPos                  LONG
AllowMove                   BYTE
SetonHighEdge               BYTE
SetonLowEdge                BYTE

                            CODE
                            ReturnValue = Level:Benign
                            IF SELF.MovingSplit = TRUE
                              IF SELF.MovingDirection = JNDSplitMove:EastWest  ! VerticalBar
                                 CurrentSize = SELF.FEQBeingMoved{PROP:Width}
                                 CurrentPos = SELF.FEQBeingMoved{PROP:XPos}
                                 PointerPos = MOUSEX()
                              ELSE   ! A Horizontal Bar
                                 CurrentSize = SELF.FEQBeingMoved{PROP:Height}
                                 CurrentPos = SELF.FEQBeingMoved{PROP:YPos}
                                 PointerPos = MOUSEY()
                              END !IF

                              PointerPos = PointerPos - SELF.PointerBarOffset   ! 2-27-2201 subtract grabbing line offset

                              AllowMove = FALSE
                              SetOnHighEdge = FALSE
                              SetOnLowEdge = FALSE

                              IF (CurrentPos > SELF.MinimumPos) AND ((CurrentPos + CurrentSize) < SELF.MaximumPos)
                                  AllowMove = TRUE

                              ELSE   ! We've hit an edge
                                  IF (CurrentPos <= SELF.MinimumPos)
                                    IF (PointerPos > SELF.MinimumPos) AND (SELF.MaximumPos > SELF.MinimumPos) ! 2-13-1999 -
                                      AllowMove = TRUE                                                        ! Account for
                                    ELSE                                                                      ! bars that
                                      SetonLowEdge = TRUE                                                     ! cannot move.
                                    END !IF

                                  ELSIF ((CurrentPos + CurrentSize) >= SELF.MaximumPos)
                                    IF (PointerPos < SELF.MaximumPos) AND (SELF.MaximumPos > SELF.MinimumPos) ! 2-13-1999 -
                                      AllowMove = TRUE                                                        ! ditto
                                    ELSE
                                      SetOnHighEdge = TRUE
                                    END !IF
                                  END !IF
                              END !IF

                      !        LocalRedraw = FALSE


                              IF AllowMove = TRUE
                                IF PointerPos < SELF.MinimumPos
                                  PointerPos = SELF.MinimumPos

                                ELSIF PointerPos > SELF.MaximumPos
                                  PointerPos = SELF.MaximumPos                      

                                END !IF

                                IF SELF.MovingDirection = JNDSplitMove:EastWest  ! VerticalBar
                                   SELF.NewBarPosX = PointerPos
                                ELSE
                                   SELF.NewBarPosY = PointerPos
                                END !IF
                               
                              ELSE

                                IF SetOnHighEdge = TRUE
                                  IF SELF.MovingDirection = JNDSplitMove:EastWest  ! VerticalBar
                                    SELF.NewBarPosX = SELF.MaximumPos
                                  ELSE
                                    SELF.NewBarPosY = SELF.MaximumPos
                                  END !IF

                                ELSIF SetOnLowEdge = TRUE
                                  IF SELF.MovingDirection = JNDSplitMove:EastWest  ! VerticalBar
                                     SELF.NewBarPosX = SELF.MinimumPos
                                  ELSE
                                     SELF.NewBarPosY = SELF.MinimumPos
                                  END !IF

                                END !IF
                              END !IF

                              IF SELF.MovingDirection = JNDSplitMove:EastWest  ! VerticalBar
                                 CurrentPos = SELF.NewBarPosX
                              ELSE
                                 CurrentPos = SELF.NewBarPosY
                              END !IF

                              IF CurrentPos <> SELF.SaveCurrentPos
                                IF SELF.SplitBeingMovedRedraw = TRUE
                                  SELF.RedrawFields(SELF.SplitBeingMoved)
                                END !IF

                                IF SELF.MovingDirection = JNDSplitMove:EastWest  ! VerticalBar
                                  SELF.FEQBeingMoved{PROP:XPos} = SELF.NewBarPosX
                                  SELF.OverLayBoxFEQ{PROP:XPos} = SELF.NewBarPosX
                                ELSE
                                  SELF.FEQBeingMoved{PROP:YPos} = SELF.NewBarPosY
                                  SELF.OverLayBoxFEQ{PROP:YPos} = SELF.NewBarPosY
                                END !IF

                          IF  SELF.SplitBeingMovedRedraw = TRUE
                                DISPLAY(SELF.OverLayBoxFEQ)
                          END !IF

                                SELF.SaveCurrentPos = CurrentPos
                              END !IF
                            END !IF
                            RETURN(ReturnValue)

JNDSplitManagerClass.TakeMouseUpEvent PROCEDURE()   ! Was TakeDragEvent before C5.5 Patch 5
ReturnValue                 BYTE

                            CODE
                              ReturnValue = Level:Benign
                              IF SELF.MovingSplit = TRUE  ! We Were Moving
                                SELF.MovingSplit = FALSE  ! Not moving any more
                                SETCURSOR()
                                SELF.OverLayBoxFEQ{PROP:Hide} = 1
                                SELF.RedrawFields(SELF.SplitBeingMoved,TRUE)  ! Final Redraw

                                SELF.ReSetBarLook(SELF.SplitBeingMoved)  ! Added 2-28-2001
                                SELF.DraggingStopped(SELF.SplitBeingMoved)
                              END !IF
                            RETURN(ReturnValue)

JNDSplitManagerClass.TakeDraggingEvent PROCEDURE()
ReturnValue                 BYTE
Counter                     LONG

                            CODE
                            ReturnValue = Level:Benign
                            IF SELF.MovingSplit = FALSE   ! We are not already dragging
                              SELF.SQ.FEQ = FIELD()
                              GET(SELF.SQ,SELF.SQ.FEQ)

                              IF NOT ERRORCODE()    ! If a FEQ was found
                                SELF.MovingSplit = TRUE
                                SELF.SplitBeingMoved = SELF.SQ.BarHandle
                                SELF.FEQBeingMoved = SELF.SQ.FEQ
                                SELF.SplitBeingMovedRedraw = SELF.SQ.RedrawWhileMoving

                                IF SELF.SQ.SplitType = JNDSplitType:Vertical
                                  SELF.MovingDirection = JNDSplitMove:EastWest
                                  SELF.SaveCurrentPos = SELF.FEQBeingMoved{PROP:XPos}
                                  SELF.PointerBarOffset = MOUSEX() - SELF.SaveCurrentPos
                                  SETCURSOR(CURSOR:SizeWE)
                                ELSE
                                  SELF.MovingDirection = JNDSplitMove:NorthSouth
                                  SELF.SaveCurrentPos = SELF.FEQBeingMoved{PROP:YPos}
                                  SELF.PointerBarOffset = MOUSEY() - SELF.SaveCurrentPos
                                  SETCURSOR(CURSOR:sizeNS)
                                END !IF

                                IF SELF.PointerBarOffset < 0  ! Just to be safe....
                                  SELF.PointerBarOffset = 0
                                END !IF

                                SELF.SetMovingLimits(SELF.SplitBeingMoved,SELF.MovingDirection)
                                SELF.SaveBarLook(SELF.SplitBeingMoved)  ! Added - JMG 2-28-2001
                                SELF.DraggingStarted(SELF.SplitBeingMoved)

                                
                          ! New 8-9-2001: set the look of the shadowing panel box
                          IF SELF.SplitBeingMovedRedraw = TRUE
                                SELF.OverlayBoxFEQ{PROP:XPos} = SELF.FEQBeingMoved{PROP:XPos}
                                SELF.OverlayBoxFEQ{PROP:YPos} = SELF.FEQBeingMoved{PROP:YPos}
                                SELF.OverlayBoxFEQ{PROP:Width} = SELF.FEQBeingMoved{PROP:Width}
                                SELF.OverlayBoxFEQ{PROP:Height} = SELF.FEQBeingMoved{PROP:Height}

                                LOOP Counter = 1 TO 3
                                  IF Counter <> 2
                                    SELF.OverlayBoxFEQ{PROP:Bevel,Counter} = SELF.FEQBeingMoved{PROP:Bevel,Counter}
                                  ELSE
                                    IF (SELF.FEQBeingMoved{PROP:Bevel,Counter} = 0) AND (SELF.FEQBeingMoved{PROP:Bevel,Counter - 1} = 0)  ! Workaround for differences in Inner Bevel of panel vs. region
                                      SELF.OverlayBoxFEQ{PROP:Bevel,Counter} = -1
                                    ELSE
                                      SELF.OverlayBoxFEQ{PROP:Bevel,Counter} = SELF.FEQBeingMoved{PROP:Bevel,Counter}
                                    END !IF
                                  END !IF
                                END !LOOP

                                SELF.OverlayBoxFEQ{PROP:Color} = SELF.FEQBeingMoved{PROP:Color}
                                SELF.OverlayBoxFEQ{PROP:Fill} = SELF.FEQBeingMoved{PROP:Fill}

                                
                                SELF.FEQBeingMoved{PROP:Hide} = 1
                                SELF.OverLayBoxFEQ{PROP:Hide} = 0
                                
                                DISPLAY(SELF.OverLayBoxFEQ)
                            END !IF
                              END !IF
                            END !IF

                            RETURN(ReturnValue)

JNDSplitManagerClass.RedrawFields     PROCEDURE(LONG BarHandle,BYTE Final=0) ! Redraws the Fields

BarPos                       LONG
BarSize                      LONG

FEQMoveDeferQ              QUEUE
FEQBeingMoved                LONG
FieldPos                     LONG
FieldSize                    LONG
HideSet                      BYTE
MoveIt                       BYTE
PlaceIt                      BYTE
Offsetit                     LONG
                           END !QUEUE

HiddenBarFlag              BYTE

Count                      LONG


                                CODE
                                FREE(FEQMoveDeferQ)
                                HiddenBarFlag = FALSE

                                CASE SELF.MovingDirection
                                  OF JNDSplitMove:NorthSouth  ! Horizontal
                                     BarPos = SELF.NewBarPosY !  SELF.FEQBeingMoved{PROP:YPos}
                                     BarSize = SELF.FEQBeingMoved{PROP:Height}

                                  OF JNDSplitMove:EastWest    ! Vertical
                                     BarPos = SELF.NewBarPosX !  SELF.FEQBeingMoved{PROP:XPos}
                                     BarSize = SELF.FEQBeingMoved{PROP:Width}
                                END !CASE

                                LOOP Count = 1 TO RECORDS(SELF.SFQ)   ! Loop through all fields
                                  GET(SELF.SFQ,Count)

                                  IF SELF.SFQ.BarHandle = BarHandle   ! SELF.SplitBeingMoved
                                    CASE SELF.SFQ.Placement
                                      OF JNDSplitPlacement:Above
                                      OROF JNDSplitPlacement:Below
                                        FEQMoveDeferQ.FieldPos = SELF.SFQ.FEQ{PROP:YPos}
                                        FEQMoveDeferQ.FieldSize = SELF.SFQ.FEQ{PROP:Height}
                          
                                      OF JNDSplitPlacement:Left
                                      OROF JNDSplitPlacement:Right
                                        FEQMoveDeferQ.FieldPos = SELF.SFQ.FEQ{PROP:XPos}
                                        FEQMoveDeferQ.FieldSize = SELF.SFQ.FEQ{PROP:Width}

                                      ELSE
                                        ASSERT(FALSE)
                                    END !CASE

                                    FEQMoveDeferQ.FEQBeingMoved = SELF.SFQ.FEQ
                                    FEQMoveDeferQ.HideSet = 0   ! Field not hidden by us.
                                    FEQMoveDeferQ.MoveIt = SELF.SFQ.MoveFlag
                                    FEQMoveDeferQ.PlaceIt = SELF.SFQ.Placement
                                    FEQMoveDeferQ.OffsetIt = SELF.SFQ.Offset

                                    ADD(FEQMoveDeferQ)  ! Add the FEQ to a Defer Move Queue

                                  END !IF
                                END !LOOP

                     !           SYSTEM{PROP:DeferMove} = RECORDS(FEQMoveDeferQ) * 2  ! Taken out 2-26-2001 to fix problem with Regions in C55gold

                                IF Final     ! Hide the split if this is the final move
                                  SELF.FEQBeingMoved{PROP:Hide} = TRUE
                                END !IF

                                LOOP Count = 1 TO RECORDS(FEQMoveDeferQ)
                                  GET(FEQMoveDeferQ,Count)

                                  CASE FEQMoveDeferQ.PlaceIt
                                    OF JNDSplitPlacement:Above
                                      IF FEQMoveDeferQ.MoveIt = FALSE  ! We are Sizing this
                                        FEQMoveDeferQ.FEQBeingMoved{PROP:Height} = (BarPos - FEQMoveDeferQ.FieldPos) - FEQMoveDeferQ.OffsetIt
                            
                                      ELSE
                                        FEQMoveDeferQ.FEQBeingMoved{PROP:YPos} = (BarPos - FEQMoveDeferQ.OffsetIt) - FEQMoveDeferQ.FieldSize
                                      END !IF
    
                                    OF JNDSplitPlacement:Below
                                      IF FEQMoveDeferQ.MoveIt = FALSE  ! We are Sizing this
                                        FEQMoveDeferQ.FEQBeingMoved{PROP:Height} = ((FEQMoveDeferQ.FieldPos + FEQMoveDeferQ.FieldSize) - (BarPos + BarSize + FEQMoveDeferQ.OffsetIt))
                                      END !IF

                                      FEQMoveDeferQ.FEQBeingMoved{PROP:YPos} = BarPos + BarSize + FEQMoveDeferQ.OffsetIt

              
                      
                                    OF JNDSplitPlacement:Left
                                      IF FEQMoveDeferQ.MoveIt = FALSE  ! We are Sizing this
                                        FEQMoveDeferQ.FEQBeingMoved{PROP:Width} = (BarPos - FEQMoveDeferQ.FieldPos) - FEQMoveDeferQ.OffsetIt
                              
                                      ELSE
                                        FEQMoveDeferQ.FEQBeingMoved{PROP:XPos} = (BarPos - FEQMoveDeferQ.OffsetIt) - FEQMoveDeferQ.FieldSize
                                      END !IF

                                    OF JNDSplitPlacement:Right
                                      IF FEQMoveDeferQ.MoveIt = FALSE  ! We are Sizing this
                                        FEQMoveDeferQ.FEQBeingMoved{PROP:Width} = ((FEQMoveDeferQ.FieldPos + FEQMoveDeferQ.FieldSize) - (BarPos + BarSize + FEQMoveDeferQ.OffsetIt))
                                      END !IF

                                      FEQMoveDeferQ.FEQBeingMoved{PROP:XPos} = BarPos + BarSize + FEQMoveDeferQ.OffsetIt

                                  END !CASE

                                END !LOOP

                                FREE(FEQMoveDeferQ)

                                IF Final
                                  
                                  SELF.FEQBeingMoved{PROP:Hide} = FALSE
                                  DISPLAY(SELF.FEQBeingMoved)
                                  POST(EVENT:Sized) ! Let Resizer at it
                                END !IF
                                RETURN

JNDSplitManagerClass.GetFEQFromHandle   PROCEDURE(LONG BarHandle) ! Returns FEQ of Bar or zero
Counter     LONG
FEQofBar    LONG
                                CODE

                                FEQofBar = 0   ! No FEQ by Default
                                SELF.SQ.FEQ = FIELD()
                                GET(SELF.SQ,SELF.SQ.BarHandle)

                                IF NOT ERRORCODE()    ! If the BarHandle was found
                                  FEQofBar = SELF.SQ.FEQ
                                END !IF

                                RETURN FEQofBar

JNDSplitManagerClass.SaveBarLook      PROCEDURE(LONG BarHandle)
FEQofBar         LONG
Counter          BYTE
                                CODE
                                FEQOfBar = SELF.GetFEQFromHandle(BarHandle)
                                IF FEQofBar <> 0
                                  SELF.OrigColor = FEQofBar{PROP:Color}
                                  SELF.OrigFill = FEQofBar{PROP:Fill}
                                  LOOP Counter = 1 TO 3
                                    SELF.OrigBevel[Counter] = FEQofBar{PROP:Bevel,Counter}
                                  END !LOOP
                                  SELF.OrigHide = FEQofBar{PROP:Hide}
                                END !IF

                                RETURN


JNDSplitManagerClass.ReSetBarLook       PROCEDURE(LONG BarHandle)
FEQofBar         LONG
Counter          BYTE
                                CODE
                                FEQOfBar = SELF.GetFEQFromHandle(BarHandle)
                                IF FEQofBar <> 0
                                  FEQofBar{PROP:Color} = SELF.OrigColor
                                  FEQofBar{PROP:Fill} = SELF.OrigFill
                                  LOOP Counter = 1 TO 3
                                     FEQofBar{PROP:Bevel,Counter} = SELF.OrigBevel[Counter]
                                  END !LOOP
                                  FEQofBar{PROP:Hide} = SELF.OrigHide
                                END !IF
                                DISPLAY(FEQofBar)
                                RETURN


JNDSplitManagerClass.DraggingStarted  PROCEDURE(LONG BarHandle) ! Does nothing except in virtual
                                        CODE
                                        RETURN

JNDSplitManagerClass.DraggingStopped  PROCEDURE(LONG BarHandle) ! Does nothing except in virtual
                                        CODE
                                        RETURN
